[−][src]Struct romulus::Interpreter
The interpreter which processes lines with a romulus program
Methods
impl Interpreter[src]
pub fn new<S: AsRef<str>>(buf: S, sep: Regex) -> Result<Interpreter, String>[src]
Creates a new interpreter with a string romulus program
pub fn file<P: AsRef<Path>>(file: P, sep: Regex) -> Result<Interpreter, String>[src]
Creates a new interpreter with a the contents of a file
pub fn process<R: BufRead, W: Write>(&self, sin: &mut R, sout: &mut W)[src]
Process an input stream and writes the results for it's romulus program to the output stream